import Node from '../node/Node';
import IElement from '../element/IElement';
import IParentNode from '../parent-node/IParentNode';
/**
 * DocumentFragment.
 */
export default class DocumentFragment extends Node implements IParentNode {
    nodeType: number;
    readonly children: IElement[];
    /**
     * Last element child.
     *
     * @return Element.
     */
    get childElementCount(): number;
    /**
     * First element child.
     *
     * @return Element.
     */
    get firstElementChild(): IElement;
    /**
     * Last element child.
     *
     * @return Element.
     */
    get lastElementChild(): IElement;
    /**
     * Inserts a set of Node objects or DOMString objects after the last child of the ParentNode. DOMString objects are inserted as equivalent Text nodes.
     *
     * @param nodes List of Node or DOMString.
     */
    append(...nodes: (Node | string)[]): void;
    /**
     * Inserts a set of Node objects or DOMString objects before the first child of the ParentNode. DOMString objects are inserted as equivalent Text nodes.
     *
     * @param nodes List of Node or DOMString.
     */
    prepend(...nodes: (Node | string)[]): void;
    /**
     * Replaces the existing children of a node with a specified new set of children.
     *
     * @param nodes List of Node or DOMString.
     */
    replaceChildren(...nodes: (Node | string)[]): void;
    /**
     * Query CSS selector to find matching nodes.
     *
     * @param selector CSS selector.
     * @returns Matching elements.
     */
    querySelectorAll(selector: string): IElement[];
    /**
     * Query CSS Selector to find matching node.
     *
     * @param selector CSS selector.
     * @return Matching element.
     */
    querySelector(selector: string): IElement;
    /**
     * Clones a node.
     *
     * @override
     * @param [deep=false] "true" to clone deep.
     * @return Cloned node.
     */
    cloneNode(deep?: boolean): DocumentFragment;
    /**
     * Append a child node to childNodes.
     *
     * @override
     * @param  node Node to append.
     * @return Appended node.
     */
    appendChild(node: Node): Node;
    /**
     * Remove Child element from childNodes array.
     *
     * @override
     * @param node Node to remove
     */
    removeChild(node: Node): void;
    /**
     * Inserts a node before another.
     *
     * @override
     * @param newNode Node to insert.
     * @param [referenceNode] Node to insert before.
     * @return Inserted node.
     */
    insertBefore(newNode: Node, referenceNode?: Node): Node;
}
