"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var Element_1 = __importDefault(require("../element/Element"));
var Event_1 = __importDefault(require("../../../event/Event"));
var CSSStyleDeclarationFactory_1 = __importDefault(require("../../../css/CSSStyleDeclarationFactory"));
/**
 * HTMLElement.
 */
var HTMLElement = /** @class */ (function (_super) {
    __extends(HTMLElement, _super);
    function HTMLElement() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.tabIndex = -1;
        _this.offsetHeight = 0;
        _this.offsetWidth = 0;
        _this.offsetLeft = 0;
        _this.offsetTop = 0;
        _this.clientHeight = 0;
        _this.clientWidth = 0;
        _this._style = null;
        return _this;
    }
    Object.defineProperty(HTMLElement.prototype, "innerText", {
        /**
         * Returns inner text.
         *
         * @return Text.
         */
        get: function () {
            return this.textContent;
        },
        /**
         * Sets inner text.
         *
         * @param text Text.
         */
        set: function (text) {
            this.textContent = text;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLElement.prototype, "style", {
        /**
         * Returns style.
         *
         * @return Style.
         */
        get: function () {
            var cssText = this.getAttribute('style');
            if (!this._style || this._style.cssText !== cssText) {
                this._style = {
                    cssText: cssText,
                    cssStyleDeclaration: CSSStyleDeclarationFactory_1.default.createCSSStyleDeclaration(cssText)
                };
            }
            return this._style.cssStyleDeclaration;
        },
        enumerable: false,
        configurable: true
    });
    /**
     * Triggers a click event.
     */
    HTMLElement.prototype.click = function () {
        var event = new Event_1.default('click', {
            bubbles: true,
            composed: true
        });
        event.target = this;
        event.currentTarget = this;
        this.dispatchEvent(event);
    };
    /**
     * Triggers a blur event.
     */
    HTMLElement.prototype.blur = function () {
        var event = new Event_1.default('blur', {
            bubbles: true,
            composed: true
        });
        event.target = this;
        event.currentTarget = this;
        this.dispatchEvent(event);
    };
    /**
     * Triggers a focus event.
     */
    HTMLElement.prototype.focus = function () {
        var event = new Event_1.default('focus', {
            bubbles: true,
            composed: true
        });
        event.target = this;
        event.currentTarget = this;
        this.dispatchEvent(event);
    };
    /**
     * Clones a node.
     *
     * @override
     * @param [deep=false] "true" to clone deep.
     * @return Cloned node.
     */
    HTMLElement.prototype.cloneNode = function (deep) {
        if (deep === void 0) { deep = false; }
        var clone = _super.prototype.cloneNode.call(this, deep);
        clone.tabIndex = this.tabIndex;
        clone.offsetHeight = this.offsetHeight;
        clone.offsetWidth = this.offsetWidth;
        clone.offsetLeft = this.offsetLeft;
        clone.offsetTop = this.offsetTop;
        clone.clientHeight = this.clientHeight;
        clone.clientWidth = this.clientWidth;
        return clone;
    };
    return HTMLElement;
}(Element_1.default));
exports.default = HTMLElement;
//# sourceMappingURL=HTMLElement.js.map