"use strict";
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var XMLParser_1 = __importDefault(require("../../../xml-parser/XMLParser"));
/**
 * Parent node utility.
 */
var ParentNodeUtility = /** @class */ (function () {
    function ParentNodeUtility() {
    }
    /**
     * Inserts a set of Node objects or DOMString objects after the last child of the ParentNode. DOMString objects are inserted as equivalent Text nodes.
     *
     * @param parentNode Parent node.
     * @param nodes List of Node or DOMString.
     */
    ParentNodeUtility.append = function (parentNode) {
        var nodes = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            nodes[_i - 1] = arguments[_i];
        }
        for (var _a = 0, nodes_1 = nodes; _a < nodes_1.length; _a++) {
            var node = nodes_1[_a];
            if (typeof node === 'string') {
                var newChildNodes = XMLParser_1.default.parse(parentNode.ownerDocument, node).childNodes.slice();
                for (var _b = 0, newChildNodes_1 = newChildNodes; _b < newChildNodes_1.length; _b++) {
                    var newChildNode = newChildNodes_1[_b];
                    parentNode.appendChild(newChildNode);
                }
            }
            else {
                parentNode.appendChild(node);
            }
        }
    };
    /**
     * Inserts a set of Node objects or DOMString objects before the first child of the ParentNode. DOMString objects are inserted as equivalent Text nodes.
     *
     * @param parentNode Parent node.
     * @param nodes List of Node or DOMString.
     */
    ParentNodeUtility.prepend = function (parentNode) {
        var nodes = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            nodes[_i - 1] = arguments[_i];
        }
        var firstChild = parentNode.firstChild;
        for (var _a = 0, nodes_2 = nodes; _a < nodes_2.length; _a++) {
            var node = nodes_2[_a];
            if (typeof node === 'string') {
                var newChildNodes = XMLParser_1.default.parse(parentNode.ownerDocument, node).childNodes.slice();
                for (var _b = 0, newChildNodes_2 = newChildNodes; _b < newChildNodes_2.length; _b++) {
                    var newChildNode = newChildNodes_2[_b];
                    parentNode.insertBefore(newChildNode, firstChild);
                }
            }
            else {
                parentNode.insertBefore(node, firstChild);
            }
        }
    };
    /**
     * Replaces the existing children of a ParentNode with a specified new set of children.
     *
     * @param parentNode Parent node.
     * @param nodes List of Node or DOMString.
     */
    ParentNodeUtility.replaceChildren = function (parentNode) {
        var nodes = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            nodes[_i - 1] = arguments[_i];
        }
        for (var _a = 0, _b = parentNode.childNodes.slice(); _a < _b.length; _a++) {
            var node = _b[_a];
            parentNode.removeChild(node);
        }
        this.append.apply(this, __spreadArrays([parentNode], nodes));
    };
    return ParentNodeUtility;
}());
exports.default = ParentNodeUtility;
//# sourceMappingURL=ParentNodeUtility.js.map