import HTMLElement from '../../basic/html-element/HTMLElement';
import Element from '../../basic/element/Element';
import Attr from '../../../attribute/Attr';
/**
 * HTMLFormElement.
 */
export default class HTMLFormElement extends HTMLElement {
    name: string;
    method: string;
    target: string;
    action: string;
    encoding: string;
    enctype: string;
    acceptCharset: string;
    autocomplete: string;
    noValidate: string;
    /**
     * Returns input elements.
     *
     * @returns Elements.
     */
    get elements(): Element[];
    /**
     * Returns number of input elements.
     *
     * @return Length.
     */
    get length(): number;
    /**
     * Submits form.
     */
    submit(): void;
    /**
     * Resets form.
     */
    reset(): void;
    /**
     * Reports validity.
     */
    reportValidity(): void;
    /**
     * Checks validity.
     *
     * @return "true" if validation does'nt fail.
     */
    checkValidity(): boolean;
    /**
     * Removes an Attr node.
     *
     * @override
     * @param attribute Attribute.
     */
    removeAttributeNode(attribute: Attr): void;
    /**
     * The setAttributeNode() method adds a new Attr node to the specified element.
     *
     * @override
     * @param attribute Attribute.
     * @returns Replaced attribute.
     */
    setAttributeNode(attribute: Attr): Attr;
    /**
     * Clones a node.
     *
     * @override
     * @param [deep=false] "true" to clone deep.
     * @return Cloned node.
     */
    cloneNode(deep?: boolean): HTMLFormElement;
}
