import Attr from '../../../attribute/Attr';
import HTMLElement from '../../basic/html-element/HTMLElement';
import HTMLFormElement from '../form/HTMLFormElement';
import ValidityState from './ValidityState';
/**
 * HTMLElement.
 */
export default class HTMLInputElement extends HTMLElement {
    formAction: string;
    formMethod: string;
    formNoValidate: boolean;
    name: string;
    type: string;
    disabled: boolean;
    autofocus: boolean;
    required: boolean;
    _value: string;
    checked: boolean;
    defaultChecked: boolean;
    indeterminate: boolean;
    alt: string;
    height: number;
    src: string;
    width: number;
    accept: string;
    allowdirs: string;
    autocomplete: string;
    min: string;
    max: string;
    minLength: number;
    maxLength: number;
    pattern: string;
    placeholder: string;
    readOnly: boolean;
    size: number;
    selectionStart: number;
    selectionEnd: number;
    selectionDirection: string;
    defaultValue: string;
    multiple: boolean;
    files: object[];
    step: string;
    inputmode: string;
    /**
     * Returns value.
     *
     * @return Value.
     */
    get value(): string;
    /**
     * Sets value.
     *
     * @param value Value.
     */
    set value(value: string);
    /**
     * Returns the parent form element.
     *
     * @return Form.
     */
    get form(): HTMLFormElement;
    /**
     * Returns validity state.
     *
     * @returns Validity state.
     */
    get validity(): ValidityState;
    /**
     * Returns validity message.
     *
     * @return Validation message.
     */
    get validationMessage(): string;
    /**
     * Returns "true" if it will validate.
     *
     * @return "true" if it will validate.
     */
    get willValidate(): boolean;
    /**
     * Returns value as Date.
     *
     * @returns Date.
     */
    get valueAsDate(): Date;
    /**
     * Returns value as number.
     *
     * @return Number.
     */
    get valueAsNumber(): number;
    /**
     * Checks validity.
     *
     * @return "true" if validation does'nt fail.
     */
    checkValidity(): boolean;
    /**
     * Removes an Attr node.
     *
     * @override
     * @param attribute Attribute.
     */
    removeAttributeNode(attribute: Attr): void;
    /**
     * The setAttributeNode() method adds a new Attr node to the specified element.
     *
     * @override
     * @param attribute Attribute.
     * @returns Replaced attribute.
     */
    setAttributeNode(attribute: Attr): Attr;
    /**
     * Clones a node.
     *
     * @override
     * @param [deep=false] "true" to clone deep.
     * @return Cloned node.
     */
    cloneNode(deep?: boolean): HTMLInputElement;
}
