"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var HTMLElement_1 = __importDefault(require("../../basic/html-element/HTMLElement"));
var ValidityState_1 = __importDefault(require("./ValidityState"));
/**
 * HTMLElement.
 */
var HTMLInputElement = /** @class */ (function (_super) {
    __extends(HTMLInputElement, _super);
    function HTMLInputElement() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        // Related to parent form.
        _this.formAction = '';
        _this.formMethod = '';
        _this.formNoValidate = false;
        // Any type of input
        _this.name = '';
        _this.type = 'text';
        _this.disabled = false;
        _this.autofocus = false;
        _this.required = false;
        _this._value = '';
        // Type specific: checkbox/radio
        _this.checked = false;
        _this.defaultChecked = false;
        _this.indeterminate = false;
        // Type specific: image
        _this.alt = '';
        _this.height = 0;
        _this.src = '';
        _this.width = 0;
        // Type specific: file
        _this.accept = '';
        _this.allowdirs = '';
        // Type specific: text/number
        _this.autocomplete = '';
        _this.min = '';
        _this.max = '';
        _this.minLength = -1;
        _this.maxLength = -1;
        _this.pattern = '';
        _this.placeholder = '';
        _this.readOnly = false;
        _this.size = 0;
        // Type specific: text/password/search/tel/url/week/month
        _this.selectionStart = 0;
        _this.selectionEnd = 0;
        _this.selectionDirection = 'forward';
        // Not categorized
        _this.defaultValue = '';
        _this.multiple = false;
        _this.files = [];
        _this.step = '';
        _this.inputmode = '';
        return _this;
    }
    Object.defineProperty(HTMLInputElement.prototype, "value", {
        /**
         * Returns value.
         *
         * @return Value.
         */
        get: function () {
            return this._value;
        },
        /**
         * Sets value.
         *
         * @param value Value.
         */
        set: function (value) {
            this._value = value;
            if (this.defaultValue === null) {
                this.defaultValue = value;
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "form", {
        /**
         * Returns the parent form element.
         *
         * @return Form.
         */
        get: function () {
            var parent = this.parentNode;
            while (parent && parent.tagName !== 'FORM') {
                parent = this.parentNode;
            }
            return parent;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "validity", {
        /**
         * Returns validity state.
         *
         * @returns Validity state.
         */
        get: function () {
            return new ValidityState_1.default(this);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "validationMessage", {
        /**
         * Returns validity message.
         *
         * @return Validation message.
         */
        get: function () {
            return null;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "willValidate", {
        /**
         * Returns "true" if it will validate.
         *
         * @return "true" if it will validate.
         */
        get: function () {
            return (this.type !== 'hidden' &&
                this.type !== 'reset' &&
                this.type !== 'button' &&
                !this.disabled &&
                !this['readOnly']);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "valueAsDate", {
        /**
         * Returns value as Date.
         *
         * @returns Date.
         */
        get: function () {
            return this.value ? new Date(this.value) : null;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLInputElement.prototype, "valueAsNumber", {
        /**
         * Returns value as number.
         *
         * @return Number.
         */
        get: function () {
            return this.value ? parseFloat(this.value) : NaN;
        },
        enumerable: false,
        configurable: true
    });
    /**
     * Checks validity.
     *
     * @return "true" if validation does'nt fail.
     */
    HTMLInputElement.prototype.checkValidity = function () {
        return true;
    };
    /**
     * Removes an Attr node.
     *
     * @override
     * @param attribute Attribute.
     */
    HTMLInputElement.prototype.removeAttributeNode = function (attribute) {
        _super.prototype.removeAttributeNode.call(this, attribute);
        switch (attribute.name) {
            case 'height': // number
            case 'width': // number
            case 'size': // number
                this[attribute.name] = 0;
                break;
            case 'selectionstart': // number
                this.selectionStart = 0;
                break;
            case 'selectionend': // number
                this.selectionEnd = 0;
                break;
            case 'minlength': // number
                this.minLength = -1;
                break;
            case 'maxlength': // number
                this.maxLength = -1;
                break;
            case 'type': // string
                this[attribute.name] = 'text';
                break;
            case 'name': // string
            case 'alt': // string
            case 'min': // string
            case 'max': // string
            case 'pattern': // string
            case 'placeholder': // string
            case 'step': // string
            case 'inputmode': // string
            case 'accept': // string
            case 'allowdirs': // string
            case 'autocomplete': // string
            case 'src': // string
                this[attribute.name] = '';
                break;
            case 'defaultvalue': // string
                this.defaultValue = '';
                break;
            case 'selectiondirection': // string
                this.selectionDirection = 'forward';
                break;
            case 'value': // string
                this._value = '';
                break;
            case 'readonly': //  boolean
                this.readOnly = false;
            case 'disabled': // boolean
            case 'autofocus': // boolean
            case 'required': // boolean
            case 'indeterminate': // boolean
            case 'multiple': // boolean
            case 'checked': // boolean
                this[attribute.name] = false;
                break;
        }
    };
    /**
     * The setAttributeNode() method adds a new Attr node to the specified element.
     *
     * @override
     * @param attribute Attribute.
     * @returns Replaced attribute.
     */
    HTMLInputElement.prototype.setAttributeNode = function (attribute) {
        var replacedAttribute = _super.prototype.setAttributeNode.call(this, attribute);
        switch (attribute.name) {
            case 'height': // number
            case 'width': // number
            case 'size': // number
                this[attribute.name] = !!attribute.value ? Number(attribute.value) : 0;
                break;
            case 'selectionstart': // number
                this.selectionStart = !!attribute.value ? Number(attribute.value) : 0;
                break;
            case 'selectionend': // number
                this.selectionEnd = !!attribute.value ? Number(attribute.value) : 0;
                break;
            case 'minlength': // number
                this.minLength = !!attribute.value ? Number(attribute.value) : -1;
                break;
            case 'maxlength': // number
                this.maxLength = !!attribute.value ? Number(attribute.value) : -1;
                break;
            case 'type': // string
            case 'name': // string
            case 'alt': // string
            case 'min': // string
            case 'max': // string
            case 'pattern': // string
            case 'placeholder': // string
            case 'step': // string
            case 'inputmode': // string
            case 'accept': // string
            case 'allowdirs': // string
            case 'autocomplete': // string
            case 'src': // string
                this[attribute.name] = attribute.value || '';
                break;
            case 'defaultvalue': // string
                this.defaultValue = attribute.value || '';
                break;
            case 'selectiondirection': // string
                this.selectionDirection = attribute.value || '';
                break;
            case 'value': // string
                this._value = attribute.value || '';
                break;
            case 'readonly': //  boolean
                this.readOnly = attribute.value != null;
                break;
            case 'disabled': // boolean
            case 'autofocus': // boolean
            case 'required': // boolean
            case 'indeterminate': // boolean
            case 'multiple': // boolean
            case 'checked': // boolean
                this[attribute.name] = attribute.value != null;
                break;
        }
        return replacedAttribute;
    };
    /**
     * Clones a node.
     *
     * @override
     * @param [deep=false] "true" to clone deep.
     * @return Cloned node.
     */
    HTMLInputElement.prototype.cloneNode = function (deep) {
        if (deep === void 0) { deep = false; }
        var clone = _super.prototype.cloneNode.call(this, deep);
        clone.formAction = this.formAction;
        clone.formMethod = this.formMethod;
        clone.formNoValidate = this.formNoValidate;
        clone.name = this.name;
        clone.type = this.type;
        clone.disabled = this.disabled;
        clone.autofocus = this.autofocus;
        clone.required = this.required;
        clone._value = this._value;
        clone.checked = this.checked;
        clone.defaultChecked = this.defaultChecked;
        clone.indeterminate = this.indeterminate;
        clone.alt = this.alt;
        clone.height = this.height;
        clone.src = this.src;
        clone.width = this.width;
        clone.accept = this.accept;
        clone.allowdirs = this.allowdirs;
        clone.autocomplete = this.autocomplete;
        clone.min = this.min;
        clone.max = this.max;
        clone.minLength = this.minLength;
        clone.maxLength = this.maxLength;
        clone.pattern = this.pattern;
        clone.placeholder = this.placeholder;
        clone.readOnly = this.readOnly;
        clone.size = this.size;
        clone.selectionStart = this.selectionStart;
        clone.selectionEnd = this.selectionEnd;
        clone.selectionDirection = this.selectionDirection;
        clone.defaultValue = this.defaultValue;
        clone.multiple = this.multiple;
        clone.step = this.step;
        clone.inputmode = this.inputmode;
        return clone;
    };
    return HTMLInputElement;
}(HTMLElement_1.default));
exports.default = HTMLInputElement;
//# sourceMappingURL=HTMLInputElement.js.map