import HTMLElement from '../../basic/html-element/HTMLElement';
import Node from '../../basic/node/Node';
import HTMLFormElement from '../form/HTMLFormElement';
import Attr from '../../../attribute/Attr';
/**
 * HTMLTextAreaElement.
 */
export default class HTMLTextAreaElement extends HTMLElement {
    name: string;
    readonly type = "textarea";
    disabled: boolean;
    autofocus: boolean;
    required: boolean;
    _value: string;
    autocomplete: string;
    cols: string;
    rows: string;
    minLength: number;
    maxLength: number;
    placeholder: string;
    readOnly: boolean;
    selectionStart: number;
    selectionEnd: number;
    selectionDirection: string;
    defaultValue: string;
    inputmode: string;
    /**
     * Returns value.
     *
     * @return Value.
     */
    get value(): string;
    /**
     * Sets value.
     *
     * @param value Value.
     */
    set value(value: string);
    /**
     * Returns the parent form element.
     *
     * @return Form.
     */
    get form(): HTMLFormElement;
    /**
     * Returns text length.
     *
     * @param Text length.
     */
    get textLength(): number;
    /**
     * @override
     */
    appendChild(node: Node): Node;
    /**
     * Remove Child element from childNodes array.
     *
     * @param node Node to remove
     */
    removeChild(node: Node): void;
    /**
     * Inserts a node before another.
     *
     * @param newNode Node to insert.
     * @param referenceNode Node to insert before.
     * @return Inserted node.
     */
    insertBefore(newNode: Node, referenceNode: Node): Node;
    /**
     * Checks validity.
     *
     * @return "true" if validation does'nt fail.
     */
    checkValidity(): boolean;
    /**
     * Removes an Attr node.
     *
     * @override
     * @param attribute Attribute.
     */
    removeAttributeNode(attribute: Attr): void;
    /**
     * The setAttributeNode() method adds a new Attr node to the specified element.
     *
     * @override
     * @param attribute Attribute.
     * @returns Replaced attribute.
     */
    setAttributeNode(attribute: Attr): Attr;
    /**
     * Clones a node.
     *
     * @override
     * @param [deep=false] "true" to clone deep.
     * @return Cloned node.
     */
    cloneNode(deep?: boolean): HTMLTextAreaElement;
}
