"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var HTMLElement_1 = __importDefault(require("../../basic/html-element/HTMLElement"));
/**
 * HTMLTextAreaElement.
 */
var HTMLTextAreaElement = /** @class */ (function (_super) {
    __extends(HTMLTextAreaElement, _super);
    function HTMLTextAreaElement() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.name = '';
        _this.type = 'textarea';
        _this.disabled = false;
        _this.autofocus = false;
        _this.required = false;
        _this._value = '';
        _this.autocomplete = '';
        _this.cols = '';
        _this.rows = '';
        _this.minLength = -1;
        _this.maxLength = -1;
        _this.placeholder = '';
        _this.readOnly = false;
        _this.selectionStart = 0;
        _this.selectionEnd = 0;
        _this.selectionDirection = 'forward';
        _this.defaultValue = '';
        _this.inputmode = '';
        return _this;
    }
    Object.defineProperty(HTMLTextAreaElement.prototype, "value", {
        /**
         * Returns value.
         *
         * @return Value.
         */
        get: function () {
            return this._value;
        },
        /**
         * Sets value.
         *
         * @param value Value.
         */
        set: function (value) {
            this._value = value;
            if (this.defaultValue === null) {
                this.defaultValue = value;
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLTextAreaElement.prototype, "form", {
        /**
         * Returns the parent form element.
         *
         * @return Form.
         */
        get: function () {
            var parent = this.parentNode;
            while (parent && parent.tagName !== 'FORM') {
                parent = this.parentNode;
            }
            return parent;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(HTMLTextAreaElement.prototype, "textLength", {
        /**
         * Returns text length.
         *
         * @param Text length.
         */
        get: function () {
            return this.value.length;
        },
        enumerable: false,
        configurable: true
    });
    /**
     * @override
     */
    HTMLTextAreaElement.prototype.appendChild = function (node) {
        _super.prototype.appendChild.call(this, node);
        this.value = this.textContent;
        return node;
    };
    /**
     * Remove Child element from childNodes array.
     *
     * @param node Node to remove
     */
    HTMLTextAreaElement.prototype.removeChild = function (node) {
        _super.prototype.removeChild.call(this, node);
        this.value = this.textContent;
    };
    /**
     * Inserts a node before another.
     *
     * @param newNode Node to insert.
     * @param referenceNode Node to insert before.
     * @return Inserted node.
     */
    HTMLTextAreaElement.prototype.insertBefore = function (newNode, referenceNode) {
        _super.prototype.insertBefore.call(this, newNode, referenceNode);
        this.value = this.textContent;
        return newNode;
    };
    /**
     * Checks validity.
     *
     * @return "true" if validation does'nt fail.
     */
    HTMLTextAreaElement.prototype.checkValidity = function () {
        return true;
    };
    /**
     * Removes an Attr node.
     *
     * @override
     * @param attribute Attribute.
     */
    HTMLTextAreaElement.prototype.removeAttributeNode = function (attribute) {
        _super.prototype.removeAttributeNode.call(this, attribute);
        switch (attribute.name) {
            case 'selectionstart': // number
                this.selectionStart = 0;
                break;
            case 'selectionend': // number
                this.selectionEnd = 0;
                break;
            case 'minlength': // number
                this.minLength = -1;
                break;
            case 'maxlength': // number
                this.maxLength = -1;
                break;
            case 'name': // string
            case 'placeholder': // string
            case 'inputmode': // string
            case 'cols': // string
            case 'rows': // string
            case 'autocomplete': // string
                this[attribute.name] = '';
                break;
            case 'selectiondirection': // string
                this.selectionDirection = 'forward';
                break;
            case 'value': // string
                this._value = '';
                break;
            case 'readonly': //  boolean
                this.readOnly = false;
                break;
            case 'disabled': // boolean
            case 'autofocus': // boolean
            case 'required': // boolean
                this[attribute.name] = false;
                break;
        }
    };
    /**
     * The setAttributeNode() method adds a new Attr node to the specified element.
     *
     * @override
     * @param attribute Attribute.
     * @returns Replaced attribute.
     */
    HTMLTextAreaElement.prototype.setAttributeNode = function (attribute) {
        var replacedAttribute = _super.prototype.setAttributeNode.call(this, attribute);
        switch (attribute.name) {
            case 'selectionstart': // number
                this.selectionStart = !!attribute.value ? Number(attribute.value) : 0;
                break;
            case 'selectionend': // number
                this.selectionEnd = !!attribute.value ? Number(attribute.value) : 0;
                break;
            case 'minlength': // number
                this.minLength = !!attribute.value ? Number(attribute.value) : -1;
                break;
            case 'maxlength': // number
                this.maxLength = !!attribute.value ? Number(attribute.value) : -1;
                break;
            case 'name': // string
            case 'placeholder': // string
            case 'inputmode': // string
            case 'cols': // string
            case 'rows': // string
            case 'autocomplete': // string
                this[attribute.name] = attribute.value || '';
                break;
            case 'selectiondirection': // string
                this.selectionDirection = attribute.value || '';
                break;
            case 'value': // string
                this._value = attribute.value || '';
                break;
            case 'readonly': //  boolean
                this.readOnly = attribute.value != null;
                break;
            case 'disabled': // boolean
            case 'autofocus': // boolean
            case 'required': // boolean
                this[attribute.name] = attribute.value != null;
                break;
        }
        return replacedAttribute;
    };
    /**
     * Clones a node.
     *
     * @override
     * @param [deep=false] "true" to clone deep.
     * @return Cloned node.
     */
    HTMLTextAreaElement.prototype.cloneNode = function (deep) {
        if (deep === void 0) { deep = false; }
        var clone = _super.prototype.cloneNode.call(this, deep);
        clone.name = this.name;
        clone.disabled = this.disabled;
        clone.autofocus = this.autofocus;
        clone.required = this.required;
        clone._value = this._value;
        clone.autocomplete = this.autocomplete;
        clone.cols = this.cols;
        clone.rows = this.rows;
        clone.minLength = this.minLength;
        clone.maxLength = this.maxLength;
        clone.placeholder = this.placeholder;
        clone.readOnly = this.readOnly;
        clone.selectionStart = this.selectionStart;
        clone.selectionEnd = this.selectionEnd;
        clone.selectionDirection = this.selectionDirection;
        clone.defaultValue = this.defaultValue;
        clone.inputmode = this.inputmode;
        return clone;
    };
    return HTMLTextAreaElement;
}(HTMLElement_1.default));
exports.default = HTMLTextAreaElement;
//# sourceMappingURL=HTMLTextAreaElement.js.map