import Element from '../nodes/basic/element/Element';
import DocumentFragment from '../nodes/basic/document-fragment/DocumentFragment';
import Document from '../nodes/basic/document/Document';
/**
 * Utility for query selection in an HTML element.
 *
 * @class QuerySelector
 */
export default class QuerySelector {
    /**
     * Finds elements based on a query selector.
     *
     * @param node Node to search in.
     * @param selector Selector.
     * @returns HTML elements.
     */
    static querySelectorAll(node: Element | DocumentFragment | Document, selector: string): Element[];
    /**
     * Finds an element based on a query selector.
     *
     * @param node Node to search in.
     * @param selector Selector.
     * @return HTML element.
     */
    static querySelector(node: Element | DocumentFragment | Document, selector: string): Element;
    /**
     * Finds elements based on a query selector for a part of a list of selectors separated with comma.
     *
     * @param rootNode Root node.
     * @param nodes Nodes.
     * @param selectorParts Selector parts.
     * @param [selectorItem] Selector item.
     * @returns HTML elements.
     */
    private static findAll;
    /**
     * Finds an element based on a query selector for a part of a list of selectors separated with comma.
     *
     * @param nodes Nodes.
     * @param selector Selector.
     * @param [selectorItem] Selector item.
     * @return HTML element.
     */
    private static findFirst;
    /**
     * Splits a selector string into groups and parts.
     *
     * @param selector Selector.
     * @return HTML element.
     */
    private static getSelectorParts;
}
