import Element from '../nodes/basic/element/Element';
import Document from '../nodes/basic/document/Document';
/**
 * XML parser.
 */
export default class XMLParser {
    /**
     * Parses XML/HTML and returns a root element.
     *
     * @param {Document} document Document.
     * @param data HTML data.
     * @return Root element.
     */
    static parse(document: Document, data: string): Element;
    /**
     * Returns a tag name if element is unnestable.
     *
     * @param element Element.
     * @return Tag name if element is unnestable.
     */
    private static getUnnestableTagName;
    /**
     * Appends text and comment nodes.
     *
     * @param  {Document} document Document.
     * @param  node Node.
     * @param  text Text to search in.
     */
    private static appendTextAndCommentNodes;
    /**
     * Returns text and comment nodes from a text.
     *
     * @param  {Document} document Document.
     * @param  text Text to search in.
     * @returns Nodes.
     */
    private static getTextAndCommentNodes;
    /**
     * Returns XMLNS attribute.
     *
     * @param attributesString Raw attributes.
     */
    private static getXmlnsAttribute;
    /**
     * Sets raw attributes.
     *
     * @param element Element.
     * @param namespaceURI Namespace URI.
     * @param attributesString Raw attributes.
     */
    private static setAttributes;
    /**
     * Returns attribute name.
     *
     * @param namespaceURI Namespace URI.
     * @param name Name.
     * @returns Attribute name based on namespace.
     */
    private static _getAttributeName;
}
